==> nextcloud-30.0.12.tar.bz2: nextcloud/apps/federatedfilesharing/l10n/el.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "Μη έγκυρο Federated Cloud ID",
    "Server to server sharing is not enabled on this server" : "Ο διαμοιρασμός μεταξύ διακομιστών δεν έχει ενεργοποιηθεί σε αυτόν το διακομιστή",
    "Couldn't establish a federated share." : "Αδυναμία επίτευξης ομόσπονδου κοινόχρηστου φακέλου",
    "Couldn't establish a federated share, maybe the password was wrong." : "Δεν μπόρεσε να γίνει ένας federated διαμοιρασμός, μπορεί να ήταν λάθος το συνθηματικό",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Το αίτημα για Federate διαμοιρασμό εστάλη, θα λάβεις μια πρόσκληση. Έλεγξε τις ειδοποιήσεις.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Δεν μπόρεσε να δημιουργήσει ένα ομοσπονδιακό κοινόχρηστο, μοιάζει ο ομόσπονδος διακομιστής είναι πολύ παλαιός (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "Δεν επιτρέπεται η αποστολή ομοσπονδιακών κονόχρηστων ομάδας από αυτόν τον διακομιστή.",
    "File is already shared with %s" : "Το αρχείο είναι ήδη κοινόχρηστο με %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Η κοινή χρήση του %1$s απέτυχε, αδύνατη η εύρεση του %2$s, ίσως ο διακομιστής δεν είναι προσβάσιμος αυτήν τη στιγμή ή χρησιμοποιεί αυτό-υπογεγραμμένο πιστοποιητικό.",
    "Could not find share" : "Αδυναμία εύρεσης κοινόχρηστου",
    "Federated sharing" : "Ομόσποσνδος διαμοιρασμός",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Λάβατε {share} ως απομακρυσμένο κοινόχρηστο από {user} (εκ μέρους του {behalf})",
    "You received {share} as a remote share from {user}" : "Λάβατε {share} ως απομακρυσμένο κοινόχρηστο από {user}",
    "Accept" : "Αποδοχή",
    "Decline" : "Απόρριψη",
    "Federated Cloud Sharing" : "Διαμοιρασμός Federated Cloud",
    "Sharing" : "Διαμοιρασμός",
    "Federated file sharing" : "Federated διαμοιρασμός αρχείου",
    "Provide federated file sharing across servers" : "Παρέχει κοινής χρήσης αρχεία μεταξύ διακομιστών",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Διαμοιρασμός με εμένα μέσω του #Nextcloud Federated Cloud ID μου",
    "Copy to clipboard" : "Αντιγραφή στο πρόχειρο",
    "Copied!" : "Αντιγράφτηκε!",
    "Federated Cloud" : "Federated Cloud",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Μπορείτε να διαμοιράζεστε με οποιονδήποτε χρησιμοποιεί Nextcloud ή άλλο συμβατό διακομιστή και υπηρεσιών Open Cloud Mesh (OCM)! Απλά προσθέστε το Federated Cloud ID στο πλαίσιο διαλόγου διαμοιρασμού. Θα μοιάζει με person@cloud.example.com",
    "Share it so your friends can share files with you:" : "Διαμοιραστείτε το ώστε οι φίλοι σας να μπορούν να διαμοιράζονται αρχεία με εσάς:",
    "X (formerly Twitter)" : "X (πρώην Twitter)",
    "Mastodon" : "Mastodon",
    "Add to your website" : "Προσθήκη στην ιστοσελίδα σας",
    "Share with me via Nextcloud" : "Διαμοιραστείτε με εμένα μέσω του Nextcloud",
    "HTML Code:" : "Κώδικας HTML:",
    "Cancel" : "Άκυρο",
    "Add remote share" : "Προσθήκη απομακρυσμένου κοινόχρηστου φακέλου",
    "Remote share" : "Απομακρυσμένος κοινόχρηστος φάκελος",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Θέλετε να προσθέσουμε τον απομακρυσμένο κοινόχρηστο φάκελο {name} από {owner}@{remote}?",
    "Remote share password" : "Συνθηματικό απομακρυσμένου κοινόχρηστου φακέλου"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-30.0.15.tar.bz2: nextcloud/apps/federatedfilesharing/l10n/el.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "Μη έγκυρο Federated Cloud ID",
    "Server to server sharing is not enabled on this server" : "Ο διαμοιρασμός μεταξύ διακομιστών δεν έχει ενεργοποιηθεί σε αυτόν το διακομιστή",
    "Couldn't establish a federated share." : "Αδυναμία επίτευξης ομόσπονδου κοινόχρηστου φακέλου",
    "Couldn't establish a federated share, maybe the password was wrong." : "Δεν μπόρεσε να γίνει ένας federated διαμοιρασμός, μπορεί να ήταν λάθος το συνθηματικό",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Το αίτημα για Federate διαμοιρασμό εστάλη, θα λάβεις μια πρόσκληση. Έλεγξε τις ειδοποιήσεις.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Δεν μπόρεσε να δημιουργήσει ένα ομοσπονδιακό κοινόχρηστο, μοιάζει ο ομόσπονδος διακομιστής είναι πολύ παλαιός (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "Δεν επιτρέπεται η αποστολή ομοσπονδιακών κονόχρηστων ομάδας από αυτόν τον διακομιστή.",
    "File is already shared with %s" : "Το αρχείο είναι ήδη κοινόχρηστο με %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Η κοινή χρήση του %1$s απέτυχε, αδύνατη η εύρεση του %2$s, ίσως ο διακομιστής δεν είναι προσβάσιμος αυτήν τη στιγμή ή χρησιμοποιεί αυτό-υπογεγραμμένο πιστοποιητικό.",
    "Could not find share" : "Αδυναμία εύρεσης κοινόχρηστου",
    "Federated sharing" : "Ομόσποσνδος διαμοιρασμός",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Λάβατε {share} ως απομακρυσμένο κοινόχρηστο από {user} (εκ μέρους του {behalf})",
    "You received {share} as a remote share from {user}" : "Λάβατε {share} ως απομακρυσμένο κοινόχρηστο από {user}",
    "Accept" : "Αποδοχή",
    "Decline" : "Απόρριψη",
    "Federated Cloud Sharing" : "Διαμοιρασμός Federated Cloud",
    "Sharing" : "Διαμοιρασμός",
    "Federated file sharing" : "Federated διαμοιρασμός αρχείου",
    "Provide federated file sharing across servers" : "Παρέχει κοινής χρήσης αρχεία μεταξύ διακομιστών",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Διαμοιρασμός με εμένα μέσω του #Nextcloud Federated Cloud ID μου",
    "Share with me via Nextcloud" : "Διαμοιραστείτε με εμένα μέσω του Nextcloud",
    "Copy" : "Αντιγραφή",
    "Copied!" : "Αντιγράφτηκε!",
    "Federated Cloud" : "Federated Cloud",
    "Share it so your friends can share files with you:" : "Διαμοιραστείτε το ώστε οι φίλοι σας να μπορούν να διαμοιράζονται αρχεία με εσάς:",
    "X (formerly Twitter)" : "X (πρώην Twitter)",
    "Mastodon" : "Mastodon",
    "Add to your website" : "Προσθήκη στην ιστοσελίδα σας",
    "HTML Code:" : "Κώδικας HTML:",
    "Cancel" : "Άκυρο",
    "Add remote share" : "Προσθήκη απομακρυσμένου κοινόχρηστου φακέλου",
    "Remote share" : "Απομακρυσμένος κοινόχρηστος φάκελος",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Θέλετε να προσθέσουμε τον απομακρυσμένο κοινόχρηστο φάκελο {name} από {owner}@{remote}?",
    "Remote share password" : "Συνθηματικό απομακρυσμένου κοινόχρηστου φακέλου",
    "Copy to clipboard" : "Αντιγραφή στο πρόχειρο",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Μπορείτε να διαμοιράζεστε με οποιονδήποτε χρησιμοποιεί Nextcloud ή άλλο συμβατό διακομιστή και υπηρεσιών Open Cloud Mesh (OCM)! Απλά προσθέστε το Federated Cloud ID στο πλαίσιο διαλόγου διαμοιρασμού. Θα μοιάζει με person@cloud.example.com"
},
"nplurals=2; plural=(n != 1);");
